@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version__ = '0.0.2'
+__version__ = '0.0.3'
 
-import data
-import metrics
-import utils
+from . import data
+from . import metrics
+from . import utils
 
 __all__ = ('__version__', 'data', 'metrics', 'utils')
